DBErrorMarker

Trait DBErrorMarker 

pub trait DBErrorMarker:
    Error
    + Send
    + Sync
    + 'static {
    // Provided method
    fn is_fatal(&self) -> bool { ... }
}
Database error marker is needed to implement From conversion for Error type.

Provided Methods

fn is_fatal(&self) -> bool

Returns true if the error is fatal and execution cannot recover from it.

Defaults to true. Implementors can override this to signal recoverable errors.

Implementations on Foreign Types

Source

impl DBErrorMarker for Infallible

Implement marker for ().

Implementors